import os
import random
import string
from flask import Flask

import data.document
import app_globals

def create_app():
	app = Flask(__name__)
	
	src_path = os.path.dirname(os.path.realpath(__file__))
	data.document.set_document_root(os.path.realpath(src_path+'/../data/doc'))
	app_globals.data_root_dir = os.path.realpath(src_path+'/../data')
	
	secret_key_path = app_globals.data_root_dir + '/flask-secret-key'
	if not os.path.isfile(secret_key_path):
		new_secret_key = ''.join(random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(20))
		with open(secret_key_path, 'wb') as f:
			f.write(new_secret_key.encode())
	with open(secret_key_path, 'rb') as f:
		secret_key = f.read().decode().replace('\n', '').replace('\r', '')
	if len(secret_key) < 20:
		raise Exception("Internal error: insecure secret key")
	app.secret_key = secret_key

	from api import api_document
	app.register_blueprint(api_document.bp)
	
	from web import web_document
	app.register_blueprint(web_document.bp)
	
	from web.admin import admin
	app.register_blueprint(admin.bp)
	
	from web.admin import admin_document
	app.register_blueprint(admin_document.bp)

	return app
